@@ -298,8 +298,8 @@ class Worker(Process):
             self.on_exit(pid, exitcode)
 
         if sys.platform != 'win32':
-            self.outq.put((DEATH, (pid, exitcode)))
             try:
+                self.outq.put((DEATH, (pid, exitcode)))
                 time.sleep(1)
             finally:
                 os._exit(exitcode)
@@ -1117,8 +1117,8 @@ class Pool(object):
                     self.on_job_process_down(job, acked_by_gone)
                     if not job.ready():
                         exitcode = exitcodes.get(acked_by_gone) or 0
-                        if getattr(cleaned[acked_by_gone],
-                                   '_job_terminated', False):
+                        proc = cleaned.get(acked_by_gone)
+                        if proc and getattr(proc, '_job_terminated', False):
                             job._set_terminated(exitcode)
                         else:
                             self.on_job_process_lost(
@@ -1658,9 +1658,9 @@ class ApplyResult(object):
     def terminate(self, signum):
         self._terminated = signum
 
-    def _set_terminated(self, signum=0):
+    def _set_terminated(self, signum=None):
         try:
-            raise Terminated(-signum)
+            raise Terminated(-(signum or 0))
         except Terminated:
             self._set(None, (False, ExceptionInfo()))
 
